<script setup>
import 'mapbox-gl/dist/mapbox-gl.css';
import Highcharts from 'highcharts';
import VueMultiselect from 'vue-multiselect';
import DK_Button from '@/components/dk_Button.vue';
import { Link } from '@inertiajs/inertia-vue3';
import mapboxgl from 'mapbox-gl';
import Datepicker from '@vuepic/vue-datepicker';
import '@vuepic/vue-datepicker/dist/main.css';
import { startOfDay, endOfDay, subDays, endOfMonth, endOfYear, startOfMonth, startOfYear, subMonths } from 'date-fns';

let AppLayout;

if (window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1) {
    AppLayout = require('@/Layouts/AppLayoutWater.vue').default;
} else {
    AppLayout = require('@/Layouts/AppLayoutCity.vue').default;
}

</script>

<style>

.dp__action_row {
    border-radius: 0.5rem;
}
.dp__input_reg {
    background: none;
    border-width: 1px;
    border-color: rgba(200, 200, 200, 0.9);
    border-radius: 0.5rem;
}
.dp__pointer {
    padding-top: 0.25rem;
    padding-bottom: 0.25rem;
}
.dp__theme_light {
    --dp-background-color: rgba(0, 57, 93, 0.95);
    --dp-text-color: #e3e3e3;
    --dp-hover-color: rgba(0, 255, 255, 0.2);
    --dp-hover-text-color: #FFFAFA;
    --dp-hover-icon-color: #e3e3e3;
    --dp-primary-color: rgba(0, 255, 255, 0.5);
    --dp-primary-text-color: #FFFAFA;
    --dp-secondary-color: #959595;
    --dp-border-color: #FFFAFA;
    --dp-menu-border-color: #FFFAFA;
    --dp-border-color-hover: #FFFAFA;
    --dp-disabled-color: #959595;
    --dp-scroll-bar-background: #f3f3f3;
    --dp-scroll-bar-color: #959595;
    --dp-success-color: rgba(5, 255, 243, 0.7);
    --dp-success-color-disabled: rgba(5, 255, 243, 0.7);
    --dp-icon-color: #e3e3e3;
    --dp-danger-color: #e6002e;
    --dp-highlight-color: rgba(25, 118, 210, 0.1);
}

</style>

<template>
    <AppLayout title="Meteo">
        <div  v-if="this.screen_width >= 768" style="height: calc(100vh - 4.75rem);" class="bg-darkblue-background -z-1 overflow-y-scroll cursor-default pb-6 text-gray-light flex flex-col gap-4 2xl:gap-6 px-10">
            <div class="w-full flex flex-col items-center justify-start gap-2 pt-4">
                <div class="text-xs text-center text-gray-light flex justify-between w-full">
                    <div class="grid place-content-center justify-start justify-items-start gap-2">
                        <div class="inline-flex justify-center items-center"> <!--id="routeprofile"-->
                            <p class="text-white-snow font-light text-2xl w-full text-left">{{ this.data.name }}&nbsp;(Id:&nbsp;{{ this.data.id }})</p>
                        </div>
                    </div>

                    <div class="grid justify-items-stretch">
                        <div class="flex justify-start items-start">
                            <div class="flex gap-2">
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityReadings', { idDevice: this.data.id })">

                                    <DK_Button color="blue" :fixedSize="true">
                                        {{ this.$t("general.Readings") }}
                                    </DK_Button>

                                </Link>

                                <DK_Button color="blue" :fixedSize="true" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                    {{ this.$t("general.Back") }}
                                </DK_Button>

                            </div>
                        </div>
                    </div>
                </div>

                <div class="w-full flex justify-between items-center">

                    <Datepicker id="interval_date" class="min-w-[21rem]" v-model="date" vertical
                                :presetRanges="this.presetRanges" range @update:modelValue="methodUpdateDate" :clearable="false"
                                :format="this.methodFormatDatetoDatepicker"></Datepicker>

                    <div class="w-full flex justify-end text-xl">
                        <p class="font-semibold">{{ this.convertDate(this.data.dates[global_index]) }}</p>
                    </div>
                </div>

            </div>

            <div class="flex flex-col 2xl:flex-row gap-4 2xl:gap-6">

                <div class="w-full 2xl:w-2/5 flex flex-col justify-center gap-2 items-center baltoro-container px-6 py-4">

                    <!--<div class="w-full flex justify-start text-xl">
                        <p class="font-semibold">{{ this.convertDate(this.data.dates[global_index]) }}</p>
                    </div>-->

                    <p class="text-lg pl-2 w-full text-left">{{ this.$t('general.Hourly split') }}</p>

                    <div class="w-full flex flex-row-reverse overflow-x-scroll">
                        <div v-for="(date, index) in this.data.dates" :key="index" class="flex justify-between items-center min-w-[7rem]">

                            <div class="h-full border-gray-semimedium border-r invisible"></div>

                            <div class="flex flex-col items-center justify-center gap-0.5 text-sm py-1 m-1 w-full rounded-md cursor-pointer"
                                v-bind:class="{'bg-blue-navbar text-white-snow': date == this.data.dates[this.global_index]}"
                                v-on:click="this.global_index = index; this.rechargePage(1)">
                                <div class="flex flex-col items-center justify-center bg-gray-modal-bg py-0.5 px-1 rounded-md mb-1">
                                    <p v-if="!this.todaysDate(date.substring(0, 10))" class="text-xs"> {{ date.substring(5, 10) + ' ' }} </p>
                                    <p v-else class="text-xs"> {{ this.$t('general.Today') }} </p>
                                    <p class="text-xs">{{date.substring(11, 16)}}</p>
                                </div>
                                <i :class="this.getIconName('', this.determinarTiempo(index))" style="font-size:1.25rem; color:#FFFAFA;"></i>
                                <p>{{ this.data.data[1][index] + ' ' + this.data.units[1] }}</p>
                                <p>{{ this.data.data[2][index] + ' ' + this.data.units[2] }}</p>
                                <p>{{ this.data.data[4][index] + ' ' + this.data.units[4] }}</p>
                            </div>

                            <div v-bind:class="{'invisible' : index == 0 }" class="h-2/3 border-gray-semimedium border-r"></div>

                        </div>
                    </div>
                </div>

                <div class="w-full 2xl:w-3/5 grid grid-cols-10 gap-4 2xl:gap-6">

                    <div v-for="(name, index) in this.data.names" :key="index" class="col-span-2 baltoro-container px-6 cursor-pointer"
                        v-on:click="this.global_sensor = index; this.rechargePage(2)" v-bind:class="{'baltoro-container-selected text-white-snow': this.global_sensor == index}">

                        <div class="w-full flex justify-between items-center py-3">
                            <i :class="this.getIconName((this.data.units[index] != null ? this.data.units[index] : ''), this.data.names[index][0])" style="font-size:1.25rem; color:#FFFAFA;"></i>
                            <div class="flex gap-1 whitespace-nowrap text-lg">
                                <p>{{this.data.data[index][global_index]}}</p>
                                <p>{{this.data.units[index]}}</p>
                            </div>
                        </div>

                        <div class="w-full border-gray-semimedium border-t"></div>

                        <div class="w-full flex justify-end items-center py-2">
                            <p class="text-xs">{{name}}</p>
                        </div>

                    </div>

                </div>

            </div>

            <div class="w-full grid grid-cols-10 gap-y-4 2xl:gap-y-6">

                <div class="col-span-5 2xl:col-span-4 h-full w-full flex gap-4 2xl:gap-6">

                    <div class="baltoro-container h-full aspect-square relative flex flex-col justify-between" id="map">
                        <div class="absolute left-0 top-0 aspect-square h-full flex justify-center items-center">
                            <div id="id_chart_gauge" class="z-[150]"></div>
                        </div>
                        <img class="absolute left-0 top-0 h-full aspect-square p-14 z-[100] opacity-70" id="id_img" src="\assets\images\others\wind_rose.png" >

                        <div class="absolute w-full h-full p-4 flex flex-col justify-between">

                            <p class="text-lg z-[150]">{{ this.$t('general.Wind details') }}</p>

                            <div class="flex justify-between items-center z-[150]">
                                <div class="flex items-baseline gap-2">
                                    <i class="DK-direccion_viento" style="font-size:1rem; color:#FFFAFA;"></i>
                                    <p class="text-lg"> {{ this.windDirection(this.global_index) }} </p>
                                </div>

                                <div class="flex items-baseline gap-2 z-[150]">
                                    <i class="DK-velocidad_viento" style="font-size:1rem; color:#FFFAFA;"></i>
                                    <p class="text-lg"> {{ this.windSpeed(this.global_index) }} </p>
                                </div>

                            </div>
                        </div>
                    </div>

                    <div class="gap-4 2xl:gap-6 grid grid-rows-4 grow">

                        <div class="baltoro-container px-6 w-full h-full">
                            <div class="w-full flex justify-between items-baseline py-3">
                                <p class="text-xs">{{this.$t('general.Thermal sensation')}}</p>
                                <div class="flex gap-1 whitespace-nowrap text-lg">
                                    <p>{{this.thermalSensation(this.global_index)}}</p>
                                    <p>{{this.data.units[1]}}</p>
                                </div>
                            </div>
                        </div>

                        <div class="baltoro-container px-6 w-full h-full">
                            <div class="w-full flex justify-between items-baseline py-3">
                                <p class="text-xs">{{this.$t('general.Dew point')}}</p>
                                <div class="flex gap-1 whitespace-nowrap text-lg">
                                    <p>{{this.dewPoint(this.global_index)}}</p>
                                    <p>{{this.data.units[1]}}</p>
                                </div>
                            </div>
                        </div>

                        <div class="baltoro-container px-6 w-full h-full">
                            <div class="w-full flex justify-between items-baseline py-3">
                                <p class="text-xs">{{this.$t('general.Concentration') + ' ' + this.data.names[8]}}</p>
                                <div class="flex gap-1 whitespace-nowrap text-lg">
                                    <p>{{this.PM25Concentration(this.global_index)}}</p>
                                </div>
                            </div>
                        </div>

                        <div class="baltoro-container px-6 w-full h-full">
                            <div class="w-full flex justify-between items-baseline py-3">
                                <p class="text-xs">{{this.$t('general.Concentration') + ' ' + this.data.names[9]}}</p>
                                <div class="flex gap-1 whitespace-nowrap text-lg">
                                    <p>{{this.PM10Concentration(this.global_index)}}</p>
                                </div>
                            </div>
                        </div>

                    </div>

                </div>

                <div class="col-span-5 2xl:col-span-6 h-full baltoro-container ml-4 2xl:ml-6 flex flex-col pl-4 pr-2 py-4 gap-2">

                    <p class="text-lg pl-2">{{ this.data.names[this.global_sensor] }}</p>

                    <div class="w-full h-full" id="id_chart"></div>

                </div>

            </div>

            <div class="w-full baltoro-container p-4 flex flex-col gap-2">

                <p class="text-lg pl-2"> {{ this.$t('general.Daily summary') }} </p>

                <div class="w-full h-[15rem] flex flex-col overflow-y-scroll">
                    <div v-for="(date, index) in this.data.day.dates" :key="index" class="flex flex-col justify-between items-center w-full gap-1"
                    v-bind:class="{'hidden': this.data.day.data[1][index] == undefined}">

                        <div class="w-full border-gray-semimedium border-t invisible"></div>

                        <div class="grid grid-cols-12 place-items-center text-sm w-full rounded-md p-2 cursor-pointer"
                            v-bind:class="{'bg-blue-navbar text-white-snow': index == 0}"
                            v-on:click="this.selectDay(date)">
                            <div class="flex items-center justify-center bg-gray-modal-bg rounded-md py-1 px-2">
                                <p v-if="!this.todaysDate(date.substring(0, 10))" class="text-xs"> {{ date.substring(5, 10) }} </p>
                                <p v-else class="text-xs"> {{ this.$t('general.Today') }} </p>
                                <p class="text-xs pl-2">{{date.substring(11, 16)}}</p>
                            </div>
                            <i :class="this.getIconName('', this.determinarTiempo(index))" style="font-size:1.25rem; color:#FFFAFA;"></i>
                            <p>{{ this.data.day.data[1][index] + ' ' + this.data.units[1] }}</p>
                            <p>{{ this.data.day.data[2][index] + ' ' + this.data.units[2] }}</p>
                            <p>{{ this.data.day.data[3][index] + ' ' + this.data.units[3] }}</p>
                            <p>{{ this.data.day.data[4][index] + ' ' + this.data.units[4] }}</p>
                            <p>{{ this.data.day.data[5][index] + ' ' + this.data.units[5] }}</p>
                            <p>{{ this.data.day.data[6][index] + ' ' + this.data.units[6] }}</p>
                            <p>{{ this.data.day.data[7][index] + ' ' + this.data.units[7] }}</p>
                            <p>{{ this.data.day.data[8][index] + ' ' + this.data.units[8] }}</p>
                            <p>{{ this.data.day.data[9][index] + ' ' + this.data.units[9] }}</p>
                            <p>{{ this.data.day.data[10][index] + ' ' + this.data.units[10] }}</p>
                        </div>

                        <div v-bind:class="{'invisible' : index == this.data.day.dates.length - 1 || this.data.day.data[1][index + 1] == undefined }" class="w-full border-gray-semimedium border-t"></div>

                    </div>
                </div>

            </div>

        </div>
        <div v-else style="height: calc(100vh - 4.75rem);" class="text-gray-light bg-darkblue-background -z-1 cursor-default select-none overflow-x-hidden">

            <div class="w-full flex flex-col justify-center items-start pt-2 pb-1 gap-2">

                <div class="w-full flex flex-row justify-between px-3">
                    <div class="w-full flex flex-col justify-start">
                        <div class="flex flex-row justify-start">
                            <p class="text-white-snow font-light text-2xl text-left">{{ this.data.name }}</p>
                        </div>
                        <p class="text-white-snow font-light text-sm text-left">{{ this.data.id }}</p>
                    </div>
                    <div class="flex justify-end gap-2">
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')"
                                :href="route('cityReadings', { idDevice: this.data.id })">
                                <button type="button"
                                    class="text-white-snow button-blue hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">
                                    <i class="fa-solid fa-chart-column" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                        <div class="flex items-center justify-center">
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit'); window.history.go(-1)">
                                <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                                    <i class="fa-solid fa-arrow-left" style="font-size:0.75rem; color:#FFFAFA;"></i>
                                </button>
                            </Link>
                        </div>
                    </div>
                </div>

                <div class="w-full px-3">
                    <Datepicker id="interval_date" class="w-full justify-self-end self-end" v-model="date" vertical
                        :presetRanges="this.presetRanges" range @update:modelValue="methodUpdateDate" :clearable="false"
                        :format="this.methodFormatDatetoDatepicker"></Datepicker>
                </div>

                <div class="w-full px-3">
                    <div class="w-full flex flex-col justify-center gap-1 items-center baltoro-container py-1">

                        <!--<div class="w-full flex justify-end text-xl">
                            <p class="font-semibold">{{ this.convertDate(this.data.dates[global_index]) }}</p>
                        </div>-->

                        <p class="text-md w-full text-center">{{ this.convertDate(this.data.dates[global_index]) }}</p>


                        <div class="w-full flex flex-row-reverse overflow-x-scroll">
                            <div v-for="(date, index) in this.data.dates" :key="index" class="flex justify-between items-center min-w-[7rem]">

                                <div class="h-full border-gray-semimedium border-r invisible"></div>

                                <div class="flex flex-col items-center justify-center gap-0.5 text-sm py-1 m-1 w-full rounded-md cursor-pointer"
                                    v-bind:class="{'bg-blue-navbar text-white-snow': date == this.data.dates[this.global_index]}"
                                    v-on:click="this.global_index = index; this.rechargePage(1)">
                                    <div class="flex flex-col items-center justify-center bg-gray-modal-bg py-0.5 px-1 rounded-md mb-1">
                                        <p v-if="!this.todaysDate(date.substring(0, 10))" class="text-xs"> {{ date.substring(5, 10) + ' ' }} </p>
                                        <p v-else class="text-xs"> {{ this.$t('general.Today') }} </p>
                                        <p class="text-xs">{{date.substring(11, 16)}}</p>
                                    </div>
                                    <i :class="this.getIconName('', this.determinarTiempo(index))" style="font-size:1.25rem; color:#FFFAFA;"></i>
                                    <p>{{ this.data.data[1][index] + ' ' + this.data.units[1] }}</p>
                                    <p>{{ this.data.data[2][index] + ' ' + this.data.units[2] }}</p>
                                    <p>{{ this.data.data[4][index] + ' ' + this.data.units[4] }}</p>
                                </div>

                                <div v-bind:class="{'invisible' : index == 0 }" class="h-2/3 border-gray-semimedium border-r"></div>

                            </div>
                        </div>
                    </div>
                </div>

                <div class="px-3 w-full flex overflow-x-auto snap-mandatory snap-x gap-3 pb-1">

                    <div v-for="(name, index) in this.data.names" :key="index" class="snap-align-none shrink-0 flex flex-col snap-always w-2/5 baltoro-container px-2 cursor-pointer"
                        v-on:click="this.global_sensor = index; this.rechargePage(2)" v-bind:class="{'baltoro-container-selected text-white-snow': this.global_sensor == index}">

                        <div class="w-full flex justify-between items-center py-2">
                            <i :class="this.getIconName((this.data.units[index] != null ? this.data.units[index] : ''), this.data.names[index][0])" style="font-size:1.25rem; color:#FFFAFA;"></i>
                            <div class="flex gap-1 whitespace-nowrap text-lg">
                                <p>{{this.data.data[index][global_index]}}</p>
                                <p>{{this.data.units[index]}}</p>
                            </div>
                        </div>

                        <div class="w-full border-gray-semimedium border-t"></div>

                        <div class="w-full flex justify-end items-center py-2">
                            <p class="text-xs">{{name}}</p>
                        </div>

                    </div>

                </div>

                <div class="w-full flex overflow-x-auto snap-mandatory snap-x pb-1 gap-3 px-3">

                    <div class="snap-center shrink-0 flex flex-col snap-always gap-2 w-full">

                        <div class="baltoro-container h-full aspect-square relative flex flex-col justify-between" id="map">
                            <div class="absolute left-0 top-0 aspect-square h-full flex justify-center items-center">
                                <div id="id_chart_gauge" class="z-[150]"></div>
                            </div>
                            <img class="absolute left-0 top-0 h-full aspect-square p-14 z-[100] opacity-70" id="id_img" src="\assets\images\others\wind_rose.png">

                            <div class="absolute w-full h-full p-4 flex flex-col justify-between">

                                <p class="text-lg z-[150]">{{ this.$t('general.Wind details') }}</p>

                                <div class="flex justify-between items-center z-[150]">
                                    <div class="flex items-baseline gap-2">
                                        <i class="DK-direccion_viento" style="font-size:1rem; color:#FFFAFA;"></i>
                                        <p class="text-lg"> {{ this.windDirection(this.global_index) }} </p>
                                    </div>

                                    <div class="flex items-baseline gap-2 z-[150]">
                                        <i class="DK-velocidad_viento" style="font-size:1rem; color:#FFFAFA;"></i>
                                        <p class="text-lg"> {{ this.windSpeed(this.global_index) }} </p>
                                    </div>

                                </div>
                            </div>
                        </div>

                        <div class="gap-2 grid grid-cols-2 grow">

                            <div class="baltoro-container px-4 w-full h-full">
                                <div class="w-full flex justify-between items-baseline py-2">
                                    <p class="text-xs">{{this.$t('general.Thermal sensation')}}</p>
                                    <div class="flex gap-1 whitespace-nowrap text-lg">
                                        <p>{{this.thermalSensation(this.global_index)}}</p>
                                        <p>{{this.data.units[1]}}</p>
                                    </div>
                                </div>
                            </div>

                            <div class="baltoro-container px-4 w-full h-full">
                                <div class="w-full flex justify-between items-baseline py-2">
                                    <p class="text-xs">{{this.$t('general.Dew point')}}</p>
                                    <div class="flex gap-1 whitespace-nowrap text-lg">
                                        <p>{{this.dewPoint(this.global_index)}}</p>
                                        <p>{{this.data.units[1]}}</p>
                                    </div>
                                </div>
                            </div>

                            <div class="baltoro-container px-4 w-full h-full">
                                <div class="w-full flex justify-between items-baseline py-2">
                                    <p class="text-xs">{{this.$t('general.Concentration') + ' ' + this.data.names[8]}}</p>
                                    <div class="flex gap-1 whitespace-nowrap text-lg">
                                        <p>{{this.PM25Concentration(this.global_index)}}</p>
                                    </div>
                                </div>
                            </div>

                            <div class="baltoro-container px-4 w-full h-full">
                                <div class="w-full flex justify-between items-baseline py-2">
                                    <p class="text-xs">{{this.$t('general.Concentration') + ' ' + this.data.names[9]}}</p>
                                    <div class="flex gap-1 whitespace-nowrap text-lg">
                                        <p>{{this.PM10Concentration(this.global_index)}}</p>
                                    </div>
                                </div>
                            </div>

                        </div>

                    </div>

                    <div class="snap-center shrink-0 flex flex-col snap-always gap-2 w-full">

                        <div class="h-full baltoro-container flex flex-col py-2 py-1 gap-2">

                            <p class="text-lg pl-2">{{ this.data.names[this.global_sensor] }}</p>

                            <div class="w-full h-full" id="id_chart"></div>

                        </div>

                    </div>

                </div>

                <div class="w-full px-3">

                    <div class="w-full baltoro-container p-4 flex flex-col gap-2">

                        <p class="text-lg pl-2"> {{ this.$t('general.Daily summary') }} </p>

                        <div class="w-full h-[15rem] flex flex-col overflow-y-scroll">
                            <div v-for="(date, index) in this.data.day.dates" :key="index" class="flex flex-col justify-between items-center w-full gap-1"
                            v-bind:class="{'hidden': this.data.day.data[1][index] == undefined}">

                                <div class="w-full border-gray-semimedium border-t invisible"></div>

                                <div class="grid grid-cols-5 place-items-center text-sm w-full rounded-md p-2 cursor-pointer"
                                    v-bind:class="{'bg-blue-navbar text-white-snow': index == 0}"
                                    v-on:click="this.selectDay(date)">
                                    <div class="flex flex-col items-center justify-center bg-gray-modal-bg rounded-md py-1 px-2">
                                        <p v-if="!this.todaysDate(date.substring(0, 10))" class="text-xs"> {{ date.substring(5, 10) }} </p>
                                        <p v-else class="text-xs"> {{ this.$t('general.Today') }} </p>
                                        <p class="text-xs">{{date.substring(11, 16)}}</p>
                                    </div>
                                    <i :class="this.getIconName('', this.determinarTiempo(index))" style="font-size:1.25rem; color:#FFFAFA;"></i>
                                    <p>{{ this.data.day.data[1][index] + ' ' + this.data.units[1] }}</p>
                                    <p>{{ this.data.day.data[2][index] + ' ' + this.data.units[2] }}</p>
                                    <!--<p>{{ this.data.day.data[3][index] + ' ' + this.data.units[3] }}</p>-->
                                    <p>{{ this.data.day.data[4][index] + ' ' + this.data.units[4] }}</p>
                                    <!--<p>{{ this.data.day.data[5][index] + ' ' + this.data.units[5] }}</p>-->
                                    <!--<p>{{ this.data.day.data[6][index] + ' ' + this.data.units[6] }}</p>-->
                                    <!--<p>{{ this.data.day.data[7][index] + ' ' + this.data.units[7] }}</p>-->
                                    <!--<p>{{ this.data.day.data[8][index] + ' ' + this.data.units[8] }}</p>-->
                                    <!--<p>{{ this.data.day.data[9][index] + ' ' + this.data.units[9] }}</p>-->
                                    <!--<p>{{ this.data.day.data[10][index] + ' ' + this.data.units[10] }}</p>-->
                                </div>

                                <div v-bind:class="{'invisible' : index == this.data.day.dates.length - 1 || this.data.day.data[1][index + 1] == undefined }" class="w-full border-gray-semimedium border-t"></div>

                            </div>
                        </div>

                    </div>
                </div>

            </div>
        </div>
    </AppLayout>
</template>

<script>
export default {
    props: [ 'data', 'user'],

    data() {
        return {
            screen_width: 0,
            Back: localStorage.getItem('Back'),
            Highcharts: require('highcharts'),
            Charts: [],
            global_index: 0,
            global_sensor: 1,
            date: undefined,

            //FORMATS
            formatDate: (date, utc) => {
                date = new Date(date);
                // utc en 0 para formatear hora local del usuario, 1 para formatear UTC
                if (utc == 0) { date.setHours(date.getHours() + this.user.timezone_offset) }
                else if (utc == -1) { date.setHours(date.getHours() - this.user.timezone_offset) }
                return (
                    date.getFullYear() + "-" +
                    ((date.getMonth() + 1 + '').length < 2 ? "0" + (date.getMonth() + 1) : (date.getMonth() + 1)) + "-" +
                    ((date.getDate() + '').length < 2 ? "0" + date.getDate() : date.getDate()) + " " +
                    ((date.getHours() + '').length < 2 ? "0" + date.getHours() : date.getHours()) + ":" +
                    ((date.getMinutes() + '').length < 2 ? "0" + date.getMinutes() : date.getMinutes()) + ":" +
                    ((date.getSeconds() + '').length < 2 ? "0" + date.getSeconds() : date.getSeconds())
                );
            },

            convertDate(date) {
                var diasSemana = ['Sun_full', 'Mon_full', 'Tue_full', 'Wed_full', 'Thu_full', 'Fri_full', 'Sat_full'];

                var meses = ['Jan_full', 'Feb_full', 'Mar_full', 'Apr_full', 'May_full', 'Jun_full', 'Jul_full', 'Aug_full', 'Sep_full', 'Oct_full', 'Nov_full', 'Dec_full'];

                var fecha = new Date(date);
                fecha.setHours(fecha.getHours() + this.user.timezone_offset)

                var diaSemana = this.$t('general.' + diasSemana[fecha.getUTCDay()]);
                var dia = fecha.getUTCDate();
                var mes = this.$t('general.' + meses[fecha.getUTCMonth()]);
                var anio = fecha.getUTCFullYear();
                var hora = (fecha.getUTCHours()).toString().length != 2 ? '0' + fecha.getUTCHours() : fecha.getUTCHours();
                var minutos = (fecha.getUTCMinutes()).toString().length != 2 ? '0' + fecha.getUTCMinutes() : fecha.getUTCMinutes();
                var segundos = (fecha.getUTCSeconds()).toString().length != 2 ? '0' + fecha.getUTCSeconds() : fecha.getUTCSeconds();

                if(this.user.language == 'es'){
                    var resultado = diaSemana + ' ' + dia + ' de ' + mes + ' ' + anio + ' a las ' + hora + ':' + minutos + ':' + segundos;
                }else if(this.user.language == 'en'){
                    var resultado = diaSemana + ' ' + dia + ' ' + mes + ' ' + anio + ' at ' + hora + ':' + minutos + ':' + segundos;
                }

                return resultado;
            },

            todaysDate(date) {
                const today = new Date();
                const year = today.getFullYear();
                const month = String(today.getMonth() + 1).padStart(2, "0");
                const day = String(today.getDate()).padStart(2, "0");

                const formattedDate = `${year}-${month}-${day}`;

                return (formattedDate == date)
            },

            presetRanges: [
                { label: this.$t("general." + "Today"), range: [startOfDay(new Date()), new Date()] },
                { label: this.$t("general." + "Yesterday"), range: [startOfDay(subDays(new Date(), 1)), endOfDay(subDays(new Date(), 1))] },
                { label: this.$t("general." + "Last 7 Days"), range: [new Date().setDate(new Date().getDate() - 7), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "Last 14 Days"), range: [new Date().setDate(new Date().getDate() - 14), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "Last 30 Days"), range: [new Date().setDate(new Date().getDate() - 30), new Date().setDate(new Date().getDate())] },
                { label: this.$t("general." + "This month"), range: [startOfMonth(new Date()), new Date()] },
                { label: this.$t("general." + "Last month"), range: [startOfMonth(subMonths(new Date(), 1)), endOfMonth(subMonths(new Date(), 1))] }
            ],

        }
    },

    beforeCreate() {
        this.$i18n.locale = this.user.language
    },

    beforeMount() {
        this.screen_width = window.screen.width;
    },

    mounted() {

        //this.mqtt_connection(this.data.id);

        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        mapboxgl.accessToken = 'pk.eyJ1IjoiZGF0YWtvcnVtLWRldmVsb3AiLCJhIjoiY2w0ODhqOXc2MDR1MjNjbzJ2YnZkdjNhYSJ9.pVPMnmkwOuF4DonlbNkkEw';

        require('highcharts/highcharts-more')(this.Highcharts);

        let formatDate = this.formatDate;

        this.Charts['default'] = {
            chart: {
                zoomType: 'x',
                backgroundColor: 'transparent',
                spacingTop: 20,
                animation: {
                    duration: 150
                },
                resetZoomButton: {
                    position: {
                        align: 'left',
                        verticalAlign: 'top',
                        x: 0,
                        y: 2.5
                    },
                    theme: {
                        r: 5.6,
                    }
                }
            },
            accessibility: {
                enabled: false
            },
            title: {
                text: ''
            },
            xAxis: {
                lineColor: '#647F8C',
                visible: true,
                labels: {
                    style: {
                        color: 'rgba(200, 200, 200, 0.9)',
                        opacity: 0.7,
                    }
                },
                type: "datetime",
                dateTimeLabelFormats: {
                    //millisecond: '%H:%M:%S.%L',
                    //second: '%H:%M:%S',
                    //minute: '%H:%M',
                    hour: '%H:%M',
                    day: '%m-%d',
                    week: '%m-%d',
                    month: '%Y-%m',
                    year: '%Y'
                },
                time: {
                    timezoneOffset: new Date().getTimezoneOffset(), // Configura la zona horaria actual
                    useUTC: false // Utiliza hora local
                }
            },
            yAxis: new Array(),
            exporting: {
                enabled: false
            },
            credits: {
                enabled: false
            },
            legend: {
                enabled: false,
                itemStyle: {
                    color: 'rgba(200, 200, 200, 0.9)',
                    opacity: 0.75,
                    fontWeight: 'light'
                },
                itemHoverStyle: {
                    color: 'rgba(200, 200, 200, 0.9)',
                    opacity: 1,
                    fontWeight: 'light'
                }
            },
            tooltip: {
                shared: true,
                split: false,
                backgroundColor: 'rgba(7,82,103,0.95)',
                borderRadius: 12,
                borderWidth: 1,
                borderColor: 'rgba(250, 250, 250, 0.65)',
                padding: 6,
                formatter: function () {
                    var s = '<b>' + '<p style="font-size:12px; line-height: 12px; font-weight: 300; color:rgba(250, 250, 250, 0.95)">' + formatDate(this.x, -1) + '</p><br/>';
                    $.each(this.points, function () {
                        s += '<p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.series.name + ' </p><p style="font-size:12px; line-height: 12px; font-weight: 400; color:' + this.series.color + '">' + this.y +
                            ' ' + this.series.userOptions.tooltip.valueSuffix + '</p><br/>';
                    });

                    return s;
                },
            },
        };

        this.Charts['gauge'] = {
            chart: {
                type: 'gauge',
                backgroundColor: "transparent",
                plotBackgroundColor: null,
                plotBackgroundImage: null,
                plotBorderWidth: 0,
                plotShadow: false,
                spacing: [0, 0, 0, 0], // Ajusta los márgenes del gráfico según tus necesidades
                height: document.getElementById('id_img').clientWidth,
                width: document.getElementById('id_img').clientWidth,
            },
            title: null,
            pane: {
                startAngle: -180,
                endAngle: 180,
                background: {
                backgroundColor: "transparent",
                borderWidth: 0
                }
            },
            tooltip: {
                enabled: false
            },
            xAxis: {
                title: {
                text: "",
                style: {
                    color: "#FFFAFA",
                    fontSize: "12px",
                    fontWeight: "normal",
                    fontStyle: "normal"
                }
                },
                labels: {
                rotation: 180,
                style: {
                    color: 'white',
                    fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                    }
                }
            },
            yAxis: {
                min: 0,
                max: 360,
                tickPosition: 'outside',
                lineColor: '#05fff3',
                lineWidth: 0, // Ajusta el ancho de la línea del eje según tus necesidades
                minorTickPosition: 'outside',
                tickColor: '#05fff3',
                minorTickColor: '#05fff3',
                tickLength: 4, // Ajusta la longitud de las marcas del eje según tus necesidades
                minorTickWidth: 1,
                tickWidth: 1,
                minorTickLength: 3, // Ajusta la longitud de las marcas menores del eje según tus necesidades
                labels: {
                distance: 6, // Ajusta la distancia de las etiquetas al eje según tus necesidades
                rotation: 'auto',
                style: {
                    color: '#05fff3',
                    fontSize: '10px' // Ajusta el tamaño de la fuente de las etiquetas según tus necesidades
                }
                },
                tickPositions: [],
                offset: -10,
                endOnTick: false
            },
            plotOptions: {
                gauge: {
                    borderWidth: 0,
                    borderColor: "rgba(0,0,0,0)", // Cambia el color del borde de la serie a #05fff3
                    dataLabels: {
                        enabled: false, // Desactiva las etiquetas con el dato y su unidad
                    },
                    pivot: {
                        radius: "1%",
                        backgroundColor: "#fff", // Cambia el color del pivote a blanco
                    },
                    dial: {
                        backgroundColor: "#05fff3", // Cambia el color de la flecha a blanco
                        radius: "60%", // Ajusta el tamaño de la flecha según tus necesidades
                        baseWidth: 10, // Ajusta el ancho de la base de la flecha según tus necesidades
                        topWidth: 0, // Ajusta el ancho de la punta de la flecha según tus necesidades
                        baseLength: "85%", // Ajusta la longitud de la base de la flecha según tus necesidades
                        rearLength: "-85%", // Ajusta la longitud de la punta de la flecha según tus necesidades
                    }
                },
            },
            credits: {
                enabled: false
            },
            exporting: {
                enabled: false,
            },
        };

        const map = new mapboxgl.Map({
                attributionControl: false,
                container: "map",
                style: 'mapbox://styles/datakorum-develop/cl4cu370w000v15tal53sxn9v',
                center: [this.data.GPS_lng, this.data.GPS_lat],
                zoom: 10,
                pitch: 0,
                bearing: 0,
                interactive: false
            });

        /*const img = document.createElement('img');

        img.src = "../assets/images/markers/marker_city.png";

        const markerElement = document.createElement('div');
        markerElement.appendChild(img);

        const marker = new mapboxgl.Marker({ element: markerElement })
            .setLngLat([this.data.GPS_lng, this.data.GPS_lat])
            .addTo(map);*/

        this.rechargePage(0);

    },

    methods: {

        rechargePage(selector) {

            let formatDate = this.formatDate;

            this.date = [
                new Date(formatDate(this.data.dates[this.data.dates.length - 1], 1)),
                new Date(formatDate(this.data.dates[0], 1))
            ];

            let chart_name = this.data.names[this.global_sensor];
            let chart_data = this.data.charts[this.global_sensor];
            let chart_unit = this.data.units[this.global_sensor];

            this.Charts['default'].yAxis = (
                {
                    id: 0,
                    opposite: true,
                    gridLineColor: '#647F8C',
                    title: {
                        text: ''
                    },
                    labels: {
                        formatter: function () {
                            return this.pos + ' ' + chart_unit
                        },
                        style: {
                            color: 'rgba(200, 200, 200, 0.9)',
                            opacity: 0.7,
                        }
                    },
                    visible: true,
                }
            );

            this.Charts['default'].tooltip.valueSuffix = chart_unit;

            this.Charts['default'].series = [];

            this.Charts['default'].series.push({
                name: chart_name,
                type: 'spline',
                yAxis: 0,
                data: chart_data.filter(point => point !== undefined && point !== null),
                color: "#05fff3",
                lineWidth: 1.5,
                zIndex: 1,
                marker: {
                    enabled: false
                },
                tooltip: {
                    valueSuffix: chart_unit
                }
            });

            if(selector == 0 || selector == 2)
                this.Highcharts.chart('id_chart', this.Charts['default']);


            this.Charts['gauge'].series = [{
                name: '',
                data: [{
                    y: (parseFloat(this.data.data[5][this.global_index]) + 180) % 360,
                }],
                tooltip: {
                    valueSuffix: ''
                }
            }]

            if(selector == 0 || selector == 1){
                this.Highcharts.chart('id_chart_gauge', this.Charts['gauge']);
                //this.Highcharts.chart('id_chart_gauge_0', this.Charts['gauge']);
            }

        },

        determinarTiempo(index) {

            var temperatura = parseFloat(this.data.data[1][index]); // Celsius
            var humedad = parseFloat(this.data.data[2][index]); // %
            var velocidadViento = parseFloat(this.data.data[4][index]); // m/s
            var lluvia = parseFloat(this.data.data[6][index]); // mm/h
            var intensidadLuz = parseFloat(this.data.data[7][index]); // Klux

            switch (true){

                case lluvia > 60: return 0;
                case lluvia > 30: return 1;
                case lluvia > 1 : return 2;

                case temperatura < -1: return 3;

                case velocidadViento > 17.5: return 4;
                case velocidadViento > 7.5: return 5;

                case intensidadLuz > 25 && temperatura > 15 && humedad >= 30 && humedad <= 70: return 6;
                case intensidadLuz > 10 && humedad >= 30 && humedad <= 70: return 7;

                default: return 8;
            }

        },

        PM25Concentration(index){

            let concentration = parseFloat(this.data.data[8][index]);

            switch(true){
                case (concentration < 0): return '-';
                case (concentration <= 12): return this.$t('general.Good');
                case (concentration <= 35): return this.$t('general.Moderate');
                //case (concentration <= 55): return this.$t('general.Unhealthy for sensitive groups');
                case (concentration <= 150): return this.$t('general.Unhealthy');
                case (concentration <= 250): return this.$t('general.Very unhealthy');
                default: return this.$t('general.Dangerous');
            }
        },

        PM10Concentration(index){

            let concentration = parseFloat(this.data.data[9][index]);

            switch(true){
                case (concentration < 0): return '-';
                case (concentration <= 50): return this.$t('general.Good');
                case (concentration <= 100): return this.$t('general.Moderate');
                //case (concentration <= 150): return this.$t('general.Unhealthy for sensitive groups');
                case (concentration <= 200): return this.$t('general.Unhealthy');
                case (concentration <= 300): return this.$t('general.Very unhealthy');
                default: return this.$t('general.Dangerous');
            }
        },

        getIconName(unit, input){

            let icon;

            switch(unit){
                case 'ºC': icon = 'DK-temperatura'; break;
                case 'V': icon = 'DK-voltaje'; break;
                case 'bar': icon = 'DK-presion'; break;
                case '%': icon = 'DK-humedad'; break;
                case 'Kpa': icon = 'DK-presion_atm'; break;
                case 'm/s': icon = 'DK-velocidad_viento'; break;
                case 'º': icon = 'DK-direccion_viento'; break;
                case 'mm/h': icon = 'DK-intensidad_precipitacion'; break;
                case 'Klux': icon = 'DK-luminosidad'; break;
                case 'ug': icon = 'DK-smart_calidad_aire'; break;
                case 'dBA': icon = 'DK-ruido'; break;
            }

            if(unit == ''){
                switch(input){
                    case 7: icon = 'fa-solid fa-cloud-sun'; break;
                    case 6: icon = 'fa-solid fa-sun'; break;
                    case 3: icon = 'fa-regular fa-snowflake'; break;
                    case 2: icon = 'fa-solid fa-cloud-rain'; break;
                    case 1: icon = 'fa-solid fa-cloud-showers-heavy'; break;
                    case 0: icon = 'fa-solid fa-cloud-bolt'; break;
                    case 5: icon = 'fa-solid fa-tornado'; break;
                    case 4: icon = 'fa-solid fa-wind'; break;
                    case 8: icon = 'fa-solid fa-cloud'; break;
                }
            }

            if(icon == undefined){
                input = input.toString()
                icon = 'fa-solid fa-' + input.toLowerCase();
            }

            return icon;
        },

        thermalSensation(index){

            let TS;

            if ( this.data.data[1][index] <= 10 && this.data.data[4][index]  > 1.33){
                TS = Math.round(13.12 + ( 0.6215 * parseFloat(this.data.data[1][index]) ) - ( 11.37 ^((parseFloat(this.data.data[4][index])*3.6),0.16) ) + (0.3965 * parseFloat(this.data.data[1][index]) ) ^((parseFloat(this.data.data[4][index])*3.6),0.16) ,1);
            }else if ( (this.data.data[1][index]>10 && this.data.data[1][index]<26 ) || (this.data.data[4][index]<1.33) && this.data.data[1][index]<26){
                TS = Math.round(this.data.data[1][index],1);
            }else if (this.data.data[1][index]>26){
                TS = Math.round( -8.78469476
                            + (1.61139411  * parseFloat(this.data.data[1][index]))
                            + (2.338558839 * parseFloat(this.data.data[2][index]))
                            - (0.14611605  * parseFloat(this.data.data[1][index]))       * parseFloat(this.data.data[2][index])
                            - (0.012308094 ^(parseFloat(this.data.data[1][index]),2))
                            - (0.016424828 ^(parseFloat(this.data.data[2][index]),2))
                            + (0.002211732 ^(parseFloat(this.data.data[1][index]),2) * parseFloat(this.data.data[2][index]))
                            + (0.00072546  * parseFloat(this.data.data[1][index])        ^(parseFloat(this.data.data[2][index]),2))
                            - (0.000003582 ^(parseFloat(this.data.data[1][index]),2) ^(parseFloat(this.data.data[2][index]),2)),1);
            }

            return TS;

        },

        dewPoint(index) {
            var dew_point = (this.data.data[1][index] - (100 - this.data.data[2][index]) / 5).toFixed(1);

            return dew_point;
        },

        UVindex(index) {

            let latitud = this.data.GPS_lat;
            let longitud = this.data.GPS_lng;
            let fecha = new Date(this.data.dates[index]);

            //let indiceUV = this.calcularIndiceUV(latitud, longitud, fecha);

            // Obtener el número del día en el año
            var diaDelAnio = (Date.UTC(fecha.getFullYear(), fecha.getMonth(), fecha.getDate()) - Date.UTC(fecha.getFullYear(), 0, 0)) / 24 / 60 / 60 / 1000;

            // Calcular el índice UV
            var declinacionSolar = 23.45 * Math.sin(2 * Math.PI * (284 + diaDelAnio) / 365);
            var anguloZenital = Math.acos(Math.sin(latitud * Math.PI / 180) * Math.sin(declinacionSolar * Math.PI / 180) + Math.cos(latitud * Math.PI / 180) * Math.cos(declinacionSolar * Math.PI / 180) * Math.cos((15 * (fecha.getUTCHours() + fecha.getUTCMinutes() / 60 + fecha.getUTCSeconds() / 3600) - longitud) * Math.PI / 180));
            var indiceUV = Math.round(12 * Math.cos(anguloZenital) * 10) / 10;

            return indiceUV;

        },

        /*calcularIndiceUV(latitud, longitud, fecha) {
            // Convertir la fecha en formato YYYY-MM-DD a objeto de fecha en JavaScript
            var fechaObj = new Date(fecha);

            // Obtener el número de día del año (1 al 365/366)
            var diaDelAnio = this.obtenerDiaDelAnio(fechaObj);

            // Obtener la hora en formato decimal (0.0 a 23.99)
            var horaDecimal = fechaObj.getHours() + fechaObj.getMinutes() / 60;

            // Calcular el ángulo solar en función de la latitud, longitud y hora decimal
            var anguloSolar = this.calcularAnguloSolar(latitud, longitud, diaDelAnio, horaDecimal);

            // Calcular el índice UV utilizando el ángulo solar
            var indiceUV = this.calcularIndiceUVDesdeAngulo(anguloSolar);

            return indiceUV;
        },

        obtenerDiaDelAnio(fecha) {
            var comienzoAnio = new Date(fecha.getFullYear(), 0, 0);
            var tiempoTranscurrido = fecha - comienzoAnio;
            var diaDelAnio = Math.floor(tiempoTranscurrido / (1000 * 60 * 60 * 24));
            return diaDelAnio;
        },

        calcularAnguloSolar(latitud, longitud, diaDelAnio, horaDecimal) {
            // Convertir la latitud de grados a radianes
            var latitudRadianes = (Math.PI / 180) * latitud;

            // Calcular la declinación solar
            var declinacionSolar =
                -23.45 * Math.cos((2 * Math.PI * (diaDelAnio + 10)) / 365);

            // Calcular la hora solar
            var horaSolar = horaDecimal + longitud / 15;

            // Calcular el ángulo horario
            var anguloHorario = (Math.PI / 12) * (horaSolar - 12);

            // Calcular el ángulo de elevación solar
            var anguloElevacion =
                Math.asin(
                Math.sin(latitudRadianes) * Math.sin(declinacionSolar) +
                    Math.cos(latitudRadianes) * Math.cos(declinacionSolar) * Math.cos(anguloHorario)
                );

            return anguloElevacion;
        },

        calcularIndiceUVDesdeAngulo(anguloElevacion) {
            // Constantes para calcular el índice UV
            var K = 12.5; // Factor de corrección
            var S = 1367; // Irradiancia solar media en la órbita terrestre (W/m²)

            // Calcular la irradiación solar en la superficie terrestre
            var irradiacionSolar = S * Math.sin(anguloElevacion);

            // Calcular el índice UV utilizando la irradiación solar y el factor de corrección
            var indiceUV = irradiacionSolar * K / 1000;

            return indiceUV;
        },*/

        windDirection(index){

            let azimut = ((parseFloat(this.data.data[5][index])) + (360 / (2 * 16) ) ) % 360
            let windDirection

            for( let i = 0; i < 16; i++ ){
                if( azimut > ( i * 360 / 16) && azimut < ((i + 1) * 360 / 16)){
                    windDirection = i
                }
            }

            switch(windDirection){
                case 0: return 'N';
                case 1: return 'NNE';
                case 2: return 'NE';
                case 3: return 'ENE';
                case 4: return 'E';
                case 5: return 'ESE';
                case 6: return 'SE';
                case 7: return 'SSE';
                case 8: return 'S';
                case 9: return 'SSW';
                case 10: return 'SW';
                case 11: return 'WSW';
                case 12: return 'W';
                case 13: return 'WNW';
                case 14: return 'NW';
                case 15: return 'NNW';
            }

        },

        windSpeed(index){

            let windSpeed = parseFloat(this.data.data[4][index]);

            switch(true){
                case (windSpeed < 0): return '-';
                case (windSpeed <= 0.2): return this.$t('general.Calm');
                case (windSpeed <= 1.5): return this.$t('general.Light air');
                case (windSpeed <= 3.3): return this.$t('general.Light breeze');
                case (windSpeed <= 5.4): return this.$t('general.Gentle breeze');
                case (windSpeed <= 7.9): return this.$t('general.Moderate breeze');
                case (windSpeed <= 10.7): return this.$t('general.Fresh breeze');
                case (windSpeed <= 13.8): return this.$t('general.Strong breeze');
                case (windSpeed <= 17.1): return this.$t('general.High wind');
                case (windSpeed <= 20.7): return this.$t('general.Gale');
                case (windSpeed <= 24.4): return this.$t('general.Strong gale');
                case (windSpeed <= 28.4): return this.$t('general.Storm');
                case (windSpeed <= 32.6): return this.$t('general.Violent storm');
                default: return this.$t('general.Hurricane');
            }

        },

        methodFormatDatetoDatepicker() {
            return generateDateDatepicker(this.date)
        },

        generateDateDatepicker(date) {

            var day1 = date[0].getDate();
            var month1 = date[0].getMonth() + 1;
            var year1 = date[0].getFullYear();
            var hour1 = date[0].getHours();
            var min1 = date[0].getMinutes();

            if(month1.toString().length == 1) month1 = '0' + month1;
            if(day1.toString().length == 1) day1 = '0' + day1;
            if(hour1.toString().length == 1) hour1 = '0' + hour1;
            if(min1.toString().length == 1) min1 = '0' + min1;

            var day2 = date[1].getDate();
            var month2 = date[1].getMonth() + 1;
            var year2 = date[1].getFullYear();
            var hour2 = date[1].getHours();
            var min2 = date[1].getMinutes();

            if(month2.toString().length == 1) month2 = '0' + month2;
            if(day2.toString().length == 1) day2 = '0' + day2;
            if(hour2.toString().length == 1) hour2 = '0' + hour2;
            if(min2.toString().length == 1) min2 = '0' + min2;

            return `${year1}/${month1}/${day1} ${hour1}:${min1} `+ this.$t("general.To") +` ${year2}/${month2}/${day2} ${hour2}:${min2}`;
        },

        mqtt_connection(iddevice) {

            var mqtt_topic = "/PUSHER/@P@" + this.user.idplatform + "/G@" + this.user.idgroup_selected + "/@D@" + iddevice;

            const mqtt = require('paho-mqtt');

            const mqtt_host = 'mqtt.datakorum.app';
            const mqtt_port = 8000;
            const mqtt_path = '';

            var userName = this.user.credentials.username;
            var password = this.user.credentials.password;

            var clientId = "APPclientid_" + parseInt(Math.random() * 100, 10);

            const client = new mqtt.Client(mqtt_host, mqtt_port, mqtt_path, clientId);

            client.connect({

                useSSL: true,
                mqttVersion: 4,
                userName: userName,
                password: password,

                onSuccess: () => {
                    // función de éxito de conexión

                    client.subscribe(mqtt_topic, {

                    onSuccess: () => {
                        console.log('éxito de suscripción ' + iddevice)
                        // función de éxito de suscripción
                    },

                    onFailure: () => {
                        // función de fallo de suscripción
                        console.error('fallo de suscripción ' + iddevice)
                    }

                    });
                },

                onFailure: () => {
                    // función de fallo de conexión
                    console.error('fallo de conexión ' + iddevice)
                }

                });

                client.onConnectionLost = () => {
                // función que se ejecuta cuando perdemos la conexión
                console.error('perdida de conexión ' + iddevice)

                setTimeout(() => {
                    this.mqtt_connection(iddevice)
                }, 5000);

            };

            client.onMessageArrived = (message) => {
                // función que se ejecuta cuando llega un mensaje al topic suscrito

                var data = JSON.parse(JSON.parse(message.payloadString).frame_data);
                var when = this.formatDate(JSON.parse(message.payloadString).when * 1000);



                this.rechargePage();

            };
        },

        selectDay(date){
            if(!this.todaysDate(date.substring(0, 10))){
                this.methodUpdateDate([new Date(date),new Date(date)])
            }
        },

        methodUpdateDate(modelData) {

            this.global_index = 0;

            if( modelData[0].getFullYear() === modelData[1].getFullYear() &&
                modelData[0].getMonth() === modelData[1].getMonth() &&
                modelData[0].getDate() === modelData[1].getDate()){

                    modelData[0].setHours(0);
                    modelData[0].setMinutes(0);
                    modelData[0].setSeconds(0);

                    modelData[1].setHours(23);
                    modelData[1].setMinutes(59);
                    modelData[1].setSeconds(59);
            }

            let date_start = this.formatDate(modelData[0], -1);
            let date_end = this.formatDate(modelData[1], -1);

            window.emitter.emit('changeLoaderStatus', true, 'orbit')

            axios({
                method: 'get',
                url: window.location.origin + '/api/gateway/city/data_meteo/' + this.data.id + '/' + this.user.id + '/' + date_start + '/' + date_end + '/' + this.user.timezone_offset,
                headers: {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                    'Authorization': 'Bearer ' + this.user.token
                },
            })
                .then(response => {

                    this.data.data = response.data.data;
                    this.data.dates = response.data.dates;
                    this.data.charts = response.data.charts;
                    this.data.day = response.data.day;

                    this.rechargePage(0);

                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                })
                .catch((error) => {
                    window.emitter.emit('changeLoaderStatus', false, 'orbit')

                    if(error.response && error.response.status && error.response.status == 429){
                        window.alert( this.$t('text.Api attempts'));
                    }else{
                        return "Failed!", error;
                    }
                });
        },
    },
}
</script>
